<?php

namespace EventPortal\Providers;

use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\ServiceProvider;
use Inertia\Inertia;

class AppServiceProvider extends ServiceProvider
{
    /** @var string */
    protected $root = __DIR__.'/../..';

    public function boot(): void
    {
        $this->app->booted(function (): void {
            $this->loadRoutesFrom("{$this->root}/routes/routes.php");
        });

        $this->loadViewsFrom("{$this->root}/resources/views", 'EventPortal');
        
        $this->loadMigrationsFrom("{$this->root}/database/migrations");
        
        $this->loadFactoriesFrom("{$this->root}/database/factories");
        
        $this->publishes([
            "{$this->root}/config/defaults/event/fields.php" => config_path('/defaults/event/fields.php'),
            "{$this->root}/config/defaults/event/tableColumns.php" => config_path('/defaults/event/tableColumns.php'),
        ], 'defaults');

        $this->app->bind(\Illuminate\Contracts\Debug\ExceptionHandler::class, \EventPortal\Exceptions\Handler::class);

        Inertia::setRootView('EventPortal::app');

        Inertia::share([
            'errors' => function () {
                return session('errors') ? session('errors')->getBag('default')->getMessages() : (object) [];
            },
        ]);

        JsonResource::withoutWrapping();
    }
}
